==> swaRmverse_0.1.0.tar.gz: swaRmverse/README.md <==
# swaRmverse  <img src="man/figures/logo.png" align="right" alt="" width="120" />

<!-- badges: start -->
[![R-CMD-check](https://github.com/marinapapa/swaRmverse/actions/workflows/R-CMD-check.yml/badge.svg)](https://github.com/marinapapa/swaRmverse/actions/workflows/R-CMD-check.yml)
[![Codecov test coverage](https://codecov.io/gh/marinapapa/swaRmverse/branch/main/graph/badge.svg)](https://app.codecov.io/gh/marinapapa/swaRmverse?branch=main)

<!-- badges: end -->
## Description 
An R package for the comparative analysis of collective motion data in the swarm space. 
Based on the packages [`trackdf`](https://github.com/swarm-lab/trackdf) and [`swaRm`](https://github.com/swarm-lab/swaRm), [`swaRmverse`](https://github.com/marinapapa/swaRmverse) aims to standardize how data of collective motion are analyzed and support the comparison of properties within and across species and contexts.

[`swaRmverse`](https://github.com/marinapapa/swaRmverse) is a work in progress, functions are likely to change as the package gets developed. 

## Publication

Further information on the functionality of the package, along with some use cases, will be soon available in our accompanying publication: 

_Papadopoulou M, Garnier S, King AJ. swaRmverse: an R package for the comparative analysis of collective motion. In prep._

The swarm space and the included metrics are first described here:  

_Papadopoulou M., Furtbauer I., O'Bryan L.R., Garnier S., Georgopoulou D.G., Bracken A.M., Christensen C. and King A.J. (2023) Dynamics of collective motion across time and species. Philosophical Transactions of the Royal Society B 378.1874 <doi:10.1098/rstb.2022.0068>._

### Acknowledgements
The development of this package was supported by the [2G-SWARM](https://www.shoalgroup.org/2g-swarm) ONR grant awarded to Dr. Andrew J. King at Swansea University (UK).

==> swaRmverse_0.1.1.tar.gz: swaRmverse/README.md <==
# swaRmverse  <img src="man/figures/logo.png" align="right" alt="" width="120" />

<!-- badges: start -->
[![R-CMD-check](https://github.com/marinapapa/swaRmverse/actions/workflows/R-CMD-check.yml/badge.svg)](https://github.com/marinapapa/swaRmverse/actions/workflows/R-CMD-check.yml)
[![Codecov test coverage](https://codecov.io/gh/marinapapa/swaRmverse/branch/main/graph/badge.svg)](https://app.codecov.io/gh/marinapapa/swaRmverse?branch=main)

<!-- badges: end -->
## Description 
An R package for the comparative analysis of collective motion data in the swarm space. 
Based on the packages [`trackdf`](https://github.com/swarm-lab/trackdf) and [`swaRm`](https://github.com/swarm-lab/swaRm), [`swaRmverse`](https://github.com/marinapapa/swaRmverse) aims to standardize how data of collective motion are analyzed and support the comparison of properties within and across species and contexts.

[`swaRmverse`](https://github.com/marinapapa/swaRmverse) is a work in progress, functions are likely to change as the package gets developed. 

## Publication

Further information on the functionality of the package, along with some use cases, will be soon available in our accompanying publication: 

_Papadopoulou M, Garnier S, King AJ. swaRmverse: an R package for the comparative analysis of collective motion. Under review._

The swarm space and the included metrics are first described here:  

_Papadopoulou M., Furtbauer I., O'Bryan L.R., Garnier S., Georgopoulou D.G., Bracken A.M., Christensen C. and King A.J. (2023) Dynamics of collective motion across time and species. Philosophical Transactions of the Royal Society B 378.1874 <doi:10.1098/rstb.2022.0068>._

### Acknowledgements
The development of this package was supported by the [2G-SWARM](https://www.shoalgroup.org/2g-swarm) ONR grant awarded to Dr. Andrew J. King at Swansea University (UK).
